## Overview

This repository contains the code used for pulling and air-quality data in support of the wider `aq` project. 

Generate build artifacts via ```python3 pip wheel --no-cache-dir aq-utils/ -w kubeflow/artifacts/wheels/aq-utils/```
